@@ -34,11 +34,11 @@ from gopup.event.area_baidu import migration_area_baidu
 新型冠状病毒接口
 """
 from gopup.event.covid import (
-    # covid_19_163,
-    # covid_19_dxy,
-    # covid_19_baidu,
-    covid_19_hist_city,
-    covid_19_hist_province,
+    covid_163,
+    covid_dxy,
+    covid_baidu,
+    covid_hist_city,
+    covid_hist_province,
 )
 
 # from gopup.my_fun import (gopup_test, add_sum)
